==> rust-tui-react_0.20.0.orig.tar.gz: tui-react-0.20.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.20.0 (2023-05-11)

### Chore (BREAKING)

 - <csr-id-073005de8c9177248528a4cc9be58d6cee525394/> switch to 'ratatui' in a fashion that leaves imports alone.
   However would still be a breaking change for anyone leaving `tui` in
   their dependency tree.

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 241 days passed between releases.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Merge branch 'ratatui-2' ([`948b539`](https://github.com/Byron/tui-crates/commit/948b5397c0b8317e857f79515165c04314b6838a))
    - Further updates to `crossterm` and `termion` ([`3157b3b`](https://github.com/Byron/tui-crates/commit/3157b3bf392b18f0f6be7e2c04d0b8782d76314e))
    - Switch to 'ratatui' in a fashion that leaves imports alone. ([`073005d`](https://github.com/Byron/tui-crates/commit/073005de8c9177248528a4cc9be58d6cee525394))
</details>

## 0.19.0 (2022-09-12)

Upgrade to tui 0.19.

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 231 days passed between releases.
 - 0 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.19.0 ([`6296315`](https://github.com/Byron/tui-crates/commit/629631545c7137c4071df1d895dee6e547e4d149))
    - Prepare changelog prior to release ([`2539f6e`](https://github.com/Byron/tui-crates/commit/2539f6e1a28d038523e342810b94770e57021cd2))
    - Upgrade to tui 19 ([`1b2afad`](https://github.com/Byron/tui-crates/commit/1b2afadba7064febd0d2dffc68f82419f9a4510b))
</details>

## 0.17.0 (2022-01-23)

### New Features (BREAKING)

 - <csr-id-b5dd73380c316d1722cc70ec4220d6ea9a7bf141/> upgrade to tui 0.17

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 171 days passed between releases.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.17.0 ([`4523678`](https://github.com/Byron/tui-crates/commit/4523678efbc9c876e46325682861c27ee5e7fb02))
    - Add changelog ([`221474b`](https://github.com/Byron/tui-crates/commit/221474b379a2c3c2f0c45dff5471659413bb9548))
    - Upgrade to tui 0.17 ([`b5dd733`](https://github.com/Byron/tui-crates/commit/b5dd73380c316d1722cc70ec4220d6ea9a7bf141))
</details>

## v0.16.0 (2021-08-04)

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release over the course of 93 calendar days.
 - 0 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Upgrade to tui 0.16 ([`907a5e5`](https://github.com/Byron/tui-crates/commit/907a5e591688732c3f88821daebc7ff8c010730b))
    - Changes repository paths in tui crates manifests ([`ac5c6e6`](https://github.com/Byron/tui-crates/commit/ac5c6e62c86189a72e2305d06da176821f88b180))
    - Add tui crates ([`ccb6a24`](https://github.com/Byron/tui-crates/commit/ccb6a24315a7d881e50b24e98d4720406bff16d5))
</details>

==> rust-tui-react_0.23.2.orig.tar.gz: tui-react-0.23.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.23.2 (2024-03-10)

### Bug Fixes

 - <csr-id-71c758121751994f129642ae506a6e0c3aefc59a/> fix the fix which had unexpected side-effect.
   This now mitigates the overflow while also working correctly.

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Fix the fix which had unexpected side-effect. ([`71c7581`](https://github.com/Byron/tui-crates/commit/71c758121751994f129642ae506a6e0c3aefc59a))
</details>

## 0.23.1 (2024-03-10)

### Bug Fixes

 - <csr-id-6d5e140a59a9f31d9f0c22885b10c85ff6ce845a/> prevent potential overflow during height computation

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release.
 - 35 days passed between releases.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.23.1 ([`57f7b9e`](https://github.com/Byron/tui-crates/commit/57f7b9e44ae94efceb198a7dc0487fc042d20036))
    - Prevent potential overflow during height computation ([`6d5e140`](https://github.com/Byron/tui-crates/commit/6d5e140a59a9f31d9f0c22885b10c85ff6ce845a))
</details>

## 0.23.0 (2024-02-03)

<csr-id-ca29ee1037ed9a153c3d346c231e0562ee948467/>

### Chore

 - <csr-id-ca29ee1037ed9a153c3d346c231e0562ee948467/> update ratatui to 0.26.0

### New Features (BREAKING)

 - <csr-id-943d49d47c04c4ddf36b6ade8652d234d2235961/> update ratatui to 0.26.0

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 38 days passed between releases.
 - 2 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.23.0, safety bump crosstermion v0.14.0 ([`c85ae46`](https://github.com/Byron/tui-crates/commit/c85ae466b18d6a97ddb45a7e2dce632d25ef971b))
    - Update ratatui to 0.26.0 ([`943d49d`](https://github.com/Byron/tui-crates/commit/943d49d47c04c4ddf36b6ade8652d234d2235961))
    - Update ratatui to 0.26.0 ([`ca29ee1`](https://github.com/Byron/tui-crates/commit/ca29ee1037ed9a153c3d346c231e0562ee948467))
</details>

## 0.22.0 (2023-12-26)

### New Features (BREAKING)

 - <csr-id-7b49dd81a3f7c209279e90c1110de00dfd6a0701/> upgrade to `ratatui` v0.25

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 19 days passed between releases.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.22.0, safety bump crosstermion v0.13.0 ([`b7283a5`](https://github.com/Byron/tui-crates/commit/b7283a511abadfdbbb6cfbb2832ee1d84c06815c))
    - Merge branch 'remove-termion' ([`c69813f`](https://github.com/Byron/tui-crates/commit/c69813f00e114313b206bceaa838e2fe0954f37b))
    - Upgrade to `ratatui` v0.25 ([`7b49dd8`](https://github.com/Byron/tui-crates/commit/7b49dd81a3f7c209279e90c1110de00dfd6a0701))
</details>

## 0.21.0 (2023-12-07)

<csr-id-a371272a96da49e8db82221eaf23d3aab38514d0/>

### Chore (BREAKING)

 - <csr-id-a371272a96da49e8db82221eaf23d3aab38514d0/> upgrade `ratatui` to 0.24 and `crossterm` to v0.27.
   Note that these two work together, and depend on each other.

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 210 days passed between releases.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.21.0, crosstermion v0.12.0, safety bump crosstermion v0.12.0 ([`942f0b9`](https://github.com/Byron/tui-crates/commit/942f0b97a4b86b91e26530cca914906645f87ac4))
    - Merge branch 'upgrades' ([`c6265c8`](https://github.com/Byron/tui-crates/commit/c6265c8773829f54e4acb1106d56ef2239edcab7))
    - Upgrade `ratatui` to 0.24 and `crossterm` to v0.27. ([`a371272`](https://github.com/Byron/tui-crates/commit/a371272a96da49e8db82221eaf23d3aab38514d0))
</details>

## 0.20.0 (2023-05-11)

<csr-id-073005de8c9177248528a4cc9be58d6cee525394/>

### Chore (BREAKING)

 - <csr-id-073005de8c9177248528a4cc9be58d6cee525394/> switch to 'ratatui' in a fashion that leaves imports alone.
   However would still be a breaking change for anyone leaving `tui` in
   their dependency tree.

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 4 commits contributed to the release.
 - 241 days passed between releases.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.20.0, crosstermion v0.11.0, safety bump crosstermion v0.11.0 ([`6cc6346`](https://github.com/Byron/tui-crates/commit/6cc634618e1549fcece860b7b43f5d7ee5d1d259))
    - Merge branch 'ratatui-2' ([`948b539`](https://github.com/Byron/tui-crates/commit/948b5397c0b8317e857f79515165c04314b6838a))
    - Further updates to `crossterm` and `termion` ([`3157b3b`](https://github.com/Byron/tui-crates/commit/3157b3bf392b18f0f6be7e2c04d0b8782d76314e))
    - Switch to 'ratatui' in a fashion that leaves imports alone. ([`073005d`](https://github.com/Byron/tui-crates/commit/073005de8c9177248528a4cc9be58d6cee525394))
</details>

## 0.19.0 (2022-09-12)

Upgrade to tui 0.19.

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 231 days passed between releases.
 - 0 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.19.0 ([`6296315`](https://github.com/Byron/tui-crates/commit/629631545c7137c4071df1d895dee6e547e4d149))
    - Prepare changelog prior to release ([`2539f6e`](https://github.com/Byron/tui-crates/commit/2539f6e1a28d038523e342810b94770e57021cd2))
    - Upgrade to tui 19 ([`1b2afad`](https://github.com/Byron/tui-crates/commit/1b2afadba7064febd0d2dffc68f82419f9a4510b))
</details>

## 0.17.0 (2022-01-23)

### New Features (BREAKING)

 - <csr-id-b5dd73380c316d1722cc70ec4220d6ea9a7bf141/> upgrade to tui 0.17

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 171 days passed between releases.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release tui-react v0.17.0 ([`4523678`](https://github.com/Byron/tui-crates/commit/4523678efbc9c876e46325682861c27ee5e7fb02))
    - Add changelog ([`221474b`](https://github.com/Byron/tui-crates/commit/221474b379a2c3c2f0c45dff5471659413bb9548))
    - Upgrade to tui 0.17 ([`b5dd733`](https://github.com/Byron/tui-crates/commit/b5dd73380c316d1722cc70ec4220d6ea9a7bf141))
</details>

## v0.16.0 (2021-08-04)

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release over the course of 93 calendar days.
 - 0 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Upgrade to tui 0.16 ([`907a5e5`](https://github.com/Byron/tui-crates/commit/907a5e591688732c3f88821daebc7ff8c010730b))
    - Changes repository paths in tui crates manifests ([`ac5c6e6`](https://github.com/Byron/tui-crates/commit/ac5c6e62c86189a72e2305d06da176821f88b180))
    - Add tui crates ([`ccb6a24`](https://github.com/Byron/tui-crates/commit/ccb6a24315a7d881e50b24e98d4720406bff16d5))
</details>
